Description Dictionary Super classes Methods References See Also Examples
A mlr3proba::LearnerDens implementing nonparametric density estimation from package
sm.
Calls sm::sm.density().
This Learner can be instantiated via the dictionary
mlr_learners or with the associated sugar function lrn():
1 2 | mlr_learners$get("dens.nonpar")
lrn("dens.nonpar")
|
mlr3::Learner -> mlr3proba::LearnerDens -> LearnerDensNonparametric
new()Creates a new instance of this R6 class.
LearnerDensNonparametric$new()
clone()The objects of this class are cloneable with this method.
LearnerDensNonparametric$clone(deep = FALSE)
deepWhether to make a deep clone.
Bowman, A.W. and Azzalini, A. (1997). Applied Smoothing Techniques for Data Analysis: the Kernel Approach with S-Plus Illustrations. Oxford University Press, Oxford.
Dictionary of Learners: mlr3::mlr_learners
1 2 3 4 5 6 7 | if (requireNamespace("sm")) {
learner = mlr3::lrn("dens.nonpar")
print(learner)
# available parameters:
learner$param_set$ids()
}
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.